### Adding more checks
Glad to see that you have an exciting check to implement yourself or
your work requires a different check which is not part of this repo, all you need to do is follow these simple steps:

**Steps**
1. Git [clone](https://help.github.com/articles/cloning-a-repository/) [alice](https://github.com/moengage/alice.git)
2. Go to alice directory ```cd alice/alice```
3. Open checker_imply.py
3. Just add your checker definition here in this file & in your config file
4. [Re-run](https://github.com/moengage/alice/blob/master/README.md) the project

**Requirements**
- Coding knowledge of [python](https://www.python.org/)
- Run setup file
  - python setup.py install


**Willing to contribute your new check**

Please read guidelines [here](https://github.com/moengage/alice/blob/master/.github/CONTRIBUTING.md#3-code-contributions)